@@ -53,8 +53,6 @@ public:
         argv is not modified by this constructor.  */
     Options(int argc, char** argv, const vector<string>& specs);
 
-    ~Options();
-
     /** Check if an option exists in the command line arguments.
         @param name The (long) option name.  */
     bool contains(const string& name) const;
@@ -63,8 +61,6 @@ public:
 
     string get(const string& name, const string& default_value) const;
 
-    string get(const string& name, const char* default_value) const;
-
     /** Get option value.
         @param name The (long) option name.
         @throws OptionError If option does not exist or has the wrong type. */
