@@ -28,8 +28,6 @@ bool is_ascii_space(int c)
 
 //-----------------------------------------------------------------------------
 
-Reader::~Reader() = default; // Non-inline to avoid GCC -Winline warning
-
 void Reader::consume_char([[maybe_unused]] char expected)
 {
     [[maybe_unused]] char c = read_char();
@@ -96,7 +94,7 @@ bool Reader::read(istream& in, bool check_single_tree)
         if (is_ascii_space(c))
             m_in->get();
         else
-            throw ReadError("Extra characters after end of tree.");
+            return false;
     }
 }
 
