@@ -16,7 +16,7 @@ LIBBOARDGAME_TEST_CASE(boardgame_rating_get_expected_result)
 {
     Rating a(2806);
     Rating b(2577);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(a.get_expected_result(b), 0.789, 0.001);
+    LIBBOARDGAME_CHECK_CLOSE_EPS(a.get_expected_result(b), 0.789, 0.001)
 }
 
 LIBBOARDGAME_TEST_CASE(boardgame_rating_get_expected_result_multiplayer)
@@ -25,7 +25,7 @@ LIBBOARDGAME_TEST_CASE(boardgame_rating_get_expected_result_multiplayer)
     // winning probability
     Rating a(1000);
     Rating b(1000);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(a.get_expected_result(b, 3), 0.25, 0.001);
+    LIBBOARDGAME_CHECK_CLOSE_EPS(a.get_expected_result(b, 3), 0.25, 0.001)
 }
 
 LIBBOARDGAME_TEST_CASE(boardgame_rating_update_1)
@@ -36,8 +36,8 @@ LIBBOARDGAME_TEST_CASE(boardgame_rating_update_1)
     Rating new_b = b;
     new_a.update(0, b, 10);
     new_b.update(1, a, 10);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2798, 1);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2585, 1);
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2798, 1)
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2585, 1)
 }
 
 LIBBOARDGAME_TEST_CASE(boardgame_rating_update_2)
@@ -48,8 +48,8 @@ LIBBOARDGAME_TEST_CASE(boardgame_rating_update_2)
     Rating new_b = b;
     new_a.update(1, b, 10);
     new_b.update(0, a, 10);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2808, 1);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2575, 1);
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2808, 1)
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2575, 1)
 }
 
 LIBBOARDGAME_TEST_CASE(boardgame_rating_update_3)
@@ -60,8 +60,8 @@ LIBBOARDGAME_TEST_CASE(boardgame_rating_update_3)
     Rating new_b = b;
     new_a.update(0.5, b, 10);
     new_b.update(0.5, a, 10);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2803, 1);
-    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2580, 1);
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_a.get(), 2803, 1)
+    LIBBOARDGAME_CHECK_CLOSE_EPS(new_b.get(), 2580, 1)
 }
 
 //-----------------------------------------------------------------------------
