@@ -51,11 +51,6 @@ public:
 
     const PentobiTree& get_tree() const;
 
-    /** Get the current color to play.
-        Initialized with get_to_play_default() but may be changed with
-        set_to_play(). */
-    Color get_to_play() const;
-
     /** @param mv
         @param always_create_new_node Always create a new child of the current
         node even if a child with the move already exists. */
@@ -84,12 +79,6 @@ public:
         play when navigating away from and back to the current node. */
     void set_to_play(Color c);
 
-    ColorMove get_move() const;
-
-    /** Add final score to root node if the current node is in the main
-        variation. */
-    void set_result(int score);
-
     string get_charset() const;
 
     void set_charset(const string& charset);
@@ -141,13 +130,8 @@ public:
         to the node as in libboardgame_base::back_to_main_variation() */
     void delete_all_variations();
 
-    /** Make the current node the first child of its parent. */
-    void make_first_child();
-
     void set_modified(bool is_modified = true);
 
-    void clear_modified();
-
     bool is_modified() const;
 
     /** Set the AP property at the root node. */
@@ -202,11 +186,6 @@ private:
     void update(const SgfNode& node);
 };
 
-inline void Game::clear_modified()
-{
-    m_tree.clear_modified();
-}
-
 inline double Game::get_bad_move(const SgfNode& node)
 {
     return SgfTree::get_bad_move(node);
@@ -242,21 +221,11 @@ inline double Game::get_good_move(const SgfNode& node)
     return SgfTree::get_good_move(node);
 }
 
-inline ColorMove Game::get_move() const
-{
-    return m_tree.get_move(*m_current);
-}
-
 inline string Game::get_player_name(Color c) const
 {
     return m_tree.get_player_name(c);
 }
 
-inline Color Game::get_to_play() const
-{
-    return m_bd->get_to_play();
-}
-
 inline string Game::get_round() const
 {
     return m_tree.get_round();
@@ -307,11 +276,6 @@ inline bool Game::is_modified() const
     return m_tree.is_modified();
 }
 
-inline void Game::make_first_child()
-{
-    m_tree.make_first_child(*m_current);
-}
-
 inline void Game::make_main_variation()
 {
     m_tree.make_main_variation(*m_current);
