@@ -43,27 +43,10 @@ public:
 
     bool resign() const override;
 
-    Float get_fixed_simulations() const;
-
-    double get_fixed_time() const;
-
-    /** Use a fixed number of simulations in the search.
-        If set to a value greater than zero, this value will enforce a
-        fixed number of simulations per search independent of the playing
-        level. */
-    void set_fixed_simulations(Float n);
-
-    /** Use a fixed time limit per move.
-        If set to a value greater than zero, this value will set a fixed
-        (maximum) time per search independent of the playing level. */
-    void set_fixed_time(double seconds);
-
     bool get_use_book() const;
 
     void set_use_book(bool enable);
 
-    unsigned get_level() const;
-
     void set_level(unsigned level);
 
     Search& get_search();
@@ -81,9 +64,6 @@ public:
         humans. */
     static Rating get_rating(Variant variant, unsigned level);
 
-    /** Get an estimated Elo-rating of the current level. */
-    Rating get_rating(Variant variant) const;
-
     /** Abort the current search.
         This function is intended to be called from a different thread to stop
         a currently running genmove(). The move generation will still return
@@ -119,10 +99,6 @@ private:
 
     array<float, Board::max_player_moves> m_weight_max_count_callisto_2;
 
-    Float m_fixed_simulations;
-
-    double m_fixed_time;
-
     Search m_search;
 
     Book m_book;
@@ -135,26 +111,6 @@ private:
     bool load_book(const string& filepath);
 };
 
-inline Float Player::get_fixed_simulations() const
-{
-    return m_fixed_simulations;
-}
-
-inline double Player::get_fixed_time() const
-{
-    return m_fixed_time;
-}
-
-inline unsigned Player::get_level() const
-{
-    return m_level;
-}
-
-inline Rating Player::get_rating(Variant variant) const
-{
-    return get_rating(variant, m_level);
-}
-
 inline Search& Player::get_search()
 {
     return m_search;
@@ -165,23 +121,9 @@ inline bool Player::get_use_book() const
     return m_use_book;
 }
 
-inline void Player::set_fixed_simulations(Float n)
-{
-    m_fixed_simulations = n;
-    m_fixed_time = 0;
-}
-
-inline void Player::set_fixed_time(double seconds)
-{
-    m_fixed_time = seconds;
-    m_fixed_simulations = 0;
-}
-
 inline void Player::set_level(unsigned level)
 {
     m_level = level;
-    m_fixed_simulations = 0;
-    m_fixed_time = 0;
 }
 
 inline void Player::set_use_book(bool enable)
