@@ -20,15 +20,7 @@ namespace libpentobi_mcts {
 
 using libboardgame_base::RandomGenerator;
 using libboardgame_base::Statistics;
-using libboardgame_mcts::LastGoodReply;
-using libboardgame_mcts::PlayerInt;
-using libpentobi_base::BoardConst;
-using libpentobi_base::MoveInfo;
-using libpentobi_base::MoveInfoExt;
-using libpentobi_base::Piece;
-using libpentobi_base::PieceInfo;
 using libpentobi_base::PieceSet;
-using libpentobi_base::Variant;
 
 //-----------------------------------------------------------------------------
 
@@ -62,7 +54,7 @@ public:
         board with (may avoid unnecessary BoardConst creation for game variant
         that is never used)
         @param shared_const The state shared between all threads, which
-        ist not modified during the search. The lifetime of this
+        is not modified during the search. The lifetime of this
         parameter must exceed the lifetime of the class instance. */
     State(Variant initial_variant, const SharedConst& shared_const);
 
@@ -99,7 +91,7 @@ public:
     void play_playout(Move mv);
 
     /** Check if RAVE value for this move should not be updated. */
-    bool skip_rave(Move mv) const;
+    static bool skip_rave([[maybe_unused]] Move mv) { return false; }
 
 #ifdef LIBBOARDGAME_DEBUG
     string dump() const;
@@ -478,11 +470,6 @@ inline void State::play_playout(Move mv)
     m_nu_passes = 0;
 }
 
-inline bool State::skip_rave([[maybe_unused]] Move mv) const
-{
-    return false;
-}
-
 template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
 inline void State::update_playout_features(Color c, Move mv)
 {
