@@ -11,18 +11,20 @@
 #include <fstream>
 #include <QDateTime>
 #include <QGuiApplication>
-#include <QDir>
 #include <QFileInfo>
 #include <QSettings>
+#include <QUrl>
 #include "libboardgame_base/SgfUtil.h"
 #include "libboardgame_base/TreeReader.h"
 #include "libpentobi_base/MoveMarker.h"
 #include "libpentobi_base/PentobiTreeWriter.h"
 #include "libpentobi_base/TreeUtil.h"
+
 #ifdef Q_OS_ANDROID
 #include "AndroidUtils.h"
 #endif
 
+using namespace Qt::StringLiterals;
 using libboardgame_base::get_letter_coord;
 using libboardgame_base::to_lower;
 using libboardgame_base::ArrayList;
@@ -196,17 +198,16 @@ void GameModel::autoSave()
 {
     auto& tree = m_game.get_tree();
     QSettings settings;
-    settings.setValue(QStringLiteral("variant"),
-                      to_string_id(m_game.get_variant()));
+    settings.setValue("variant"_L1, to_string_id(m_game.get_variant()));
     if (! m_file.isEmpty() && ! m_isModified)
-        settings.remove(QStringLiteral("autosave"));
+        settings.remove("autosave"_L1);
     else
-        settings.setValue(QStringLiteral("autosave"), getSgf());
-    settings.setValue(QStringLiteral("file"), m_file);
+        settings.setValue("autosave"_L1, getSgf());
+    settings.setValue("file"_L1, m_file);
     m_autosaveDate = QDateTime::currentMSecsSinceEpoch();
-    settings.setValue(QStringLiteral("autosaveDate"), m_autosaveDate);
-    settings.setValue(QStringLiteral("fileDate"), m_fileDate);
-    settings.setValue(QStringLiteral("isModified"), m_isModified);
+    settings.setValue("autosaveDate"_L1, m_autosaveDate);
+    settings.setValue("fileDate"_L1, m_fileDate);
+    settings.setValue("isModified"_L1, m_isModified);
     QVariantList location;
     uint depth = 0;
     auto node = &m_game.get_current();
@@ -219,7 +220,7 @@ void GameModel::autoSave()
         ++depth;
     }
     location.prepend(depth);
-    settings.setValue(QStringLiteral("autosaveLocation"), location);
+    settings.setValue("autosaveLocation"_L1, location);
 }
 
 void GameModel::backToMainVar()
@@ -243,19 +244,14 @@ bool GameModel::checkAutosaveModifiedOutside()
     return false;
 #else
     QSettings settings;
-    auto autosaveDate = settings.value(QStringLiteral("autosaveDate"));
+    auto autosaveDate = settings.value("autosaveDate"_L1);
     return m_autosaveDate != 0 && autosaveDate != 0
             && m_autosaveDate != autosaveDate
-            && settings.value(QStringLiteral("isModified")).toBool()
-            && settings.value(QStringLiteral("autosave")).toByteArray() != getSgf();
+            && settings.value("isModified"_L1).toBool()
+            && settings.value("autosave"_L1).toByteArray() != getSgf();
 #endif
 }
 
-bool GameModel::checkFileExists(const QString& file)
-{
-    return QFileInfo::exists(file);
-}
-
 bool GameModel::checkFileModifiedOutside()
 {
 #ifdef Q_OS_ANDROID
@@ -288,16 +284,6 @@ void GameModel::clearFile()
     emit fileChanged();
 }
 
-bool GameModel::createFolder(const QUrl& folder)
-{
-    auto localFolder = folder.toLocalFile();
-    if (! QDir().mkdir(localFolder)) {
-        m_error = QString::fromLocal8Bit(strerror(errno));
-        return false;
-    }
-    return true;
-}
-
 void GameModel::createPieceModels()
 {
     createPieceModels(Color(0));
@@ -350,6 +336,15 @@ QByteArray GameModel::encode(const QString& s)
     return s.toUtf8();
 }
 
+QString GameModel::fileToUrl(const QString& file)
+{
+#ifdef Q_OS_ANDROID
+    // We don't treat Android content URIs as URLs yet
+    return file;
+#endif
+    return QUrl::fromLocalFile(file).toString();
+}
+
 GameMove* GameModel::findMoveNext()
 {
     prepareFindMove();
@@ -461,7 +456,7 @@ QVariantList GameModel::getPieceModels(int color)
 Variant GameModel::getInitialGameVariant()
 {
     QSettings settings;
-    auto variantString = settings.value(QStringLiteral("variant")).toString();
+    auto variantString = settings.value("variant"_L1).toString();
     Variant variant;
     if (! parse_variant_id(variantString.toLocal8Bit().constData(), variant))
         variant = Variant::duo;
@@ -484,17 +479,17 @@ QString GameModel::getMoveAnnotationAtNode(const SgfNode& node) const
     try
     {
         if (m_game.get_good_move(node) == 2)
-            return QStringLiteral("‼");
+            return u"‼"_s;
         if (m_game.get_good_move(node) == 1)
-            return QStringLiteral("!");
+            return u"!"_s;
         if (m_game.is_interesting_move(node))
-            return QStringLiteral("⁉");
+            return u"⁉"_s;
         if (m_game.is_doubtful_move(node))
-            return QStringLiteral("⁈");
+            return u"⁈"_s;
         if (m_game.get_bad_move(node) == 1)
-            return QStringLiteral("?");
+            return u"?"_s;
         if (m_game.get_bad_move(node) == 2)
-            return QStringLiteral("⁇");
+            return u"⁇"_s;
     }
     catch (const SgfError&)
     {
@@ -864,26 +859,22 @@ bool GameModel::loadAutoSave()
 {
     {
         QSettings settings;
-        auto file = settings.value(QStringLiteral("file")).toString();
-        auto isModified =
-                settings.value(QStringLiteral("isModified")).toBool();
+        auto file = settings.value("file"_L1).toString();
+        auto isModified = settings.value("isModified"_L1).toBool();
         if (! file.isEmpty() && ! isModified)
         {
             if (! openFile(file))
                 return false;
             updateFileInfo(file);
             m_autosaveDate = m_fileDate;
-            settings.setValue(QStringLiteral("autosaveDate"), m_autosaveDate);
+            settings.setValue("autosaveDate"_L1, m_autosaveDate);
         }
         else
         {
-            if (! openByteArray(settings.value(
-                                    QStringLiteral("autosave")).toByteArray()))
+            if (! openByteArray(settings.value("autosave"_L1).toByteArray()))
                 return false;
-            m_fileDate = settings.value(
-                        QStringLiteral("fileDate")).toLongLong();
-            m_autosaveDate = settings.value(
-                        QStringLiteral("autosaveDate")).toLongLong();
+            m_fileDate = settings.value("fileDate"_L1).toLongLong();
+            m_autosaveDate = settings.value("autosaveDate"_L1).toLongLong();
             setFile(file);
         }
         // Sanitize isModified if value from settings is inconsistent
@@ -1026,7 +1017,7 @@ bool GameModel::openStream(istream& in)
         preparePositionChange();
         TreeReader reader;
         reader.read(in);
-        auto root = reader.get_tree_transfer_ownership();
+        auto root = reader.move_tree();
         m_game.init(root);
     }
     catch (const runtime_error& e)
@@ -1206,7 +1197,7 @@ void GameModel::restoreAutoSaveLocation()
 {
     QSettings settings;
     auto location =
-            settings.value(QStringLiteral("autosaveLocation")).value<QVariantList>();
+        settings.value("autosaveLocation"_L1).value<QVariantList>();
     if (location.empty())
         return;
     int index = 0;
@@ -1264,31 +1255,6 @@ bool GameModel::save(const QString& file)
     return true;
 }
 
-bool GameModel::saveAsciiArt(const QString& file)
-{
-#ifdef Q_OS_ANDROID
-    ostringstream out;
-    getBoard().write(out, false);
-    string s(out.str());
-    QByteArray array(&*s.begin(), s.size());
-    if (! AndroidUtils::save(file, array))
-    {
-        m_error = AndroidUtils::getError();
-        return false;
-    }
-    return true;
-#else
-    ofstream out(file.toLocal8Bit().constData());
-    getBoard().write(out, false);
-    if (! out)
-    {
-        m_error = QString::fromLocal8Bit(strerror(errno));
-        return false;
-    }
-    return true;
-#endif
-}
-
 template<typename T>
 bool GameModel::set(T& target, const T& value,
                     void (GameModel::*changedSignal)())
@@ -1350,17 +1316,17 @@ void GameModel::setMoveAnnotationAtNode(const SgfNode& node,
                                         const QString& annotation)
 {
     m_game.remove_move_annotation(node);
-    if (annotation == QStringLiteral("!"))
+    if (annotation == u"!"_s)
         m_game.set_good_move(node);
-    else if (annotation == QStringLiteral("‼"))
+    else if (annotation == u"‼"_s)
         m_game.set_good_move(node, 2);
-    else if (annotation == QStringLiteral("?"))
+    else if (annotation == u"?"_s)
         m_game.set_bad_move(node);
-    else if (annotation == QStringLiteral("⁇"))
+    else if (annotation == u"⁇"_s)
         m_game.set_bad_move(node, 2);
-    else if (annotation == QStringLiteral("⁉"))
+    else if (annotation == u"⁉"_s)
         m_game.set_interesting_move(node);
-    else if (annotation == QStringLiteral("⁈"))
+    else if (annotation == u"⁈"_s)
         m_game.set_doubtful_move(node);
     updateIsModified();
     updatePositionInfo();
@@ -1452,36 +1418,6 @@ void GameModel::setTime(const QString& time)
     updateIsModified();
 }
 
-QString GameModel::suggestFileName(const QUrl& folder,
-                                   const QString& fileEnding)
-{
-    QString suffix = QStringLiteral(".") + fileEnding;
-    if (folder.isEmpty())
-        return tr("Untitled") + suffix;
-    auto localFolder = folder.toLocalFile();
-    QString file = localFolder + '/' + tr("Untitled") + suffix;
-    if (QFileInfo::exists(file))
-        for (unsigned i = 1; ; ++i)
-        {
-            //: The argument is a number, which will be increased if a
-            //: file with the same name already exists
-            file = localFolder + '/' + tr("Untitled %1").arg(i)
-                    + suffix;
-            if (! QFileInfo::exists(file))
-                break;
-        }
-    return QUrl::fromLocalFile(file).fileName();
-}
-
-QString GameModel::suggestGameFileName(const QUrl& folder)
-{
-#ifndef Q_OS_ANDROID
-    if (! m_file.isEmpty())
-        return QUrl::fromLocalFile(m_file).fileName();
-#endif
-    return suggestFileName(folder, QStringLiteral("blksgf"));
-}
-
 void GameModel::truncate()
 {
     if (! m_game.get_current().has_parent())
@@ -1506,6 +1442,15 @@ void GameModel::undo()
     updateProperties();
 }
 
+QString GameModel::urlToFile(const QString& url)
+{
+#ifdef Q_OS_ANDROID
+    // We don't treat Android content URIs as URLs yet
+    return url;
+#endif
+    return QUrl(url).toLocalFile();
+}
+
 void GameModel::updateFileInfo(const QString& file)
 {
     setFile(file);
