@@ -7,7 +7,6 @@
 #ifndef PENTOBI_GAME_MODEL_H
 #define PENTOBI_GAME_MODEL_H
 
-#include <QUrl>
 #include "PieceModel.h"
 #include "libpentobi_base/Game.h"
 
@@ -122,8 +121,6 @@ public:
         there is no piece at this location. */
     Q_INVOKABLE PieceModel* addEmpty(const QPoint& pos);
 
-    Q_INVOKABLE bool createFolder(const QUrl& folder);
-
     Q_INVOKABLE void deleteAllVar();
 
     Q_INVOKABLE bool findNextComment();
@@ -193,8 +190,6 @@ public:
 
     Q_INVOKABLE bool save(const QString& file);
 
-    Q_INVOKABLE bool saveAsciiArt(const QString& file);
-
     Q_INVOKABLE void setMoveAnnotation(int moveNumber,
                                        const QString& annotation);
 
@@ -210,8 +205,6 @@ public:
 
     Q_INVOKABLE QString getResultMessage();
 
-    Q_INVOKABLE static bool checkFileExists(const QString& file);
-
     Q_INVOKABLE bool checkFileModifiedOutside();
 
     Q_INVOKABLE bool checkAutosaveModifiedOutside();
@@ -227,15 +220,14 @@ public:
 
     Q_INVOKABLE PieceModel* previousPiece(PieceModel* currentPickedPiece);
 
-    Q_INVOKABLE static QString suggestFileName(const QUrl& folder,
-                                               const QString& fileEnding);
-
-    Q_INVOKABLE QString suggestGameFileName(const QUrl& folder);
-
     Q_INVOKABLE QString getError() const { return m_error; }
 
     Q_INVOKABLE QVariantList getPieceModels(int color);
 
+    Q_INVOKABLE static QString fileToUrl(const QString& file);
+
+    Q_INVOKABLE static QString urlToFile(const QString& url);
+
 
     QByteArray getSgf(int indent = -1) const;
 
