@@ -11,6 +11,8 @@
 #include <QtConcurrentRun>
 #include "GameModel.h"
 
+using namespace Qt::StringLiterals;
+
 //-----------------------------------------------------------------------------
 
 PlayerModel::PlayerModel(QObject* parent)
@@ -66,8 +68,7 @@ void PlayerModel::genMoveFinished()
 
 void PlayerModel::loadBook(Variant variant)
 {
-    QFile file(QStringLiteral(":/pentobi_books/book_%1.blksgf")
-               .arg(to_string_id(variant)));
+    QFile file(":/pentobi_books/book_%1.blksgf"_L1.arg(to_string_id(variant)));
     if (! file.open(QIODevice::ReadOnly))
         return;
     QTextStream stream(&file);
